SWDEV-401489 - [ABI Break] Removed hipModuleLaunchKernelExt
Change-Id: I0b31d9db755f8a89ead203dbd238a93c18b76855
This commit is contained in:
committed by
Rakesh Roy
parent
369fdc4d87
commit
fe2d747bcc
@@ -397,7 +397,6 @@ enum hip_api_id_t {
|
|||||||
HIP_API_ID_hipMemcpyFromArrayAsync = HIP_API_ID_NONE,
|
HIP_API_ID_hipMemcpyFromArrayAsync = HIP_API_ID_NONE,
|
||||||
HIP_API_ID_hipMemcpyHtoAAsync = HIP_API_ID_NONE,
|
HIP_API_ID_hipMemcpyHtoAAsync = HIP_API_ID_NONE,
|
||||||
HIP_API_ID_hipMemcpyToArrayAsync = HIP_API_ID_NONE,
|
HIP_API_ID_hipMemcpyToArrayAsync = HIP_API_ID_NONE,
|
||||||
HIP_API_ID_hipModuleLaunchKernelExt = HIP_API_ID_NONE,
|
|
||||||
HIP_API_ID_hipSetValidDevices = HIP_API_ID_NONE,
|
HIP_API_ID_hipSetValidDevices = HIP_API_ID_NONE,
|
||||||
HIP_API_ID_hipTexObjectCreate = HIP_API_ID_NONE,
|
HIP_API_ID_hipTexObjectCreate = HIP_API_ID_NONE,
|
||||||
HIP_API_ID_hipTexObjectDestroy = HIP_API_ID_NONE,
|
HIP_API_ID_hipTexObjectDestroy = HIP_API_ID_NONE,
|
||||||
@@ -5477,8 +5476,6 @@ typedef struct hip_api_data_s {
|
|||||||
#define INIT_hipMemcpyHtoAAsync_CB_ARGS_DATA(cb_data) {};
|
#define INIT_hipMemcpyHtoAAsync_CB_ARGS_DATA(cb_data) {};
|
||||||
// hipMemcpyToArrayAsync()
|
// hipMemcpyToArrayAsync()
|
||||||
#define INIT_hipMemcpyToArrayAsync_CB_ARGS_DATA(cb_data) {};
|
#define INIT_hipMemcpyToArrayAsync_CB_ARGS_DATA(cb_data) {};
|
||||||
// hipModuleLaunchKernelExt()
|
|
||||||
#define INIT_hipModuleLaunchKernelExt_CB_ARGS_DATA(cb_data) {};
|
|
||||||
// hipSetValidDevices()
|
// hipSetValidDevices()
|
||||||
#define INIT_hipSetValidDevices_CB_ARGS_DATA(cb_data) {};
|
#define INIT_hipSetValidDevices_CB_ARGS_DATA(cb_data) {};
|
||||||
// hipTexObjectCreate()
|
// hipTexObjectCreate()
|
||||||
|
|||||||
@@ -160,7 +160,6 @@ hipModuleGetFunction
|
|||||||
hipModuleGetGlobal
|
hipModuleGetGlobal
|
||||||
hipModuleGetTexRef
|
hipModuleGetTexRef
|
||||||
hipModuleLaunchKernel
|
hipModuleLaunchKernel
|
||||||
hipModuleLaunchKernelExt
|
|
||||||
hipModuleLaunchCooperativeKernel
|
hipModuleLaunchCooperativeKernel
|
||||||
hipModuleLaunchCooperativeKernelMultiDevice
|
hipModuleLaunchCooperativeKernelMultiDevice
|
||||||
hipLaunchCooperativeKernel
|
hipLaunchCooperativeKernel
|
||||||
|
|||||||
@@ -138,7 +138,6 @@ global:
|
|||||||
hipModuleGetGlobal;
|
hipModuleGetGlobal;
|
||||||
hipModuleGetTexRef;
|
hipModuleGetTexRef;
|
||||||
hipModuleLaunchKernel;
|
hipModuleLaunchKernel;
|
||||||
hipModuleLaunchKernelExt;
|
|
||||||
hipLaunchCooperativeKernel;
|
hipLaunchCooperativeKernel;
|
||||||
hipLaunchCooperativeKernelMultiDevice;
|
hipLaunchCooperativeKernelMultiDevice;
|
||||||
hipModuleLoad;
|
hipModuleLoad;
|
||||||
|
|||||||
@@ -498,20 +498,6 @@ hipError_t hipHccModuleLaunchKernel(hipFunction_t f, uint32_t globalWorkSizeX,
|
|||||||
extra, startEvent, stopEvent));
|
extra, startEvent, stopEvent));
|
||||||
}
|
}
|
||||||
|
|
||||||
hipError_t hipModuleLaunchKernelExt(hipFunction_t f, uint32_t globalWorkSizeX,
|
|
||||||
uint32_t globalWorkSizeY, uint32_t globalWorkSizeZ,
|
|
||||||
uint32_t blockDimX, uint32_t blockDimY, uint32_t blockDimZ,
|
|
||||||
size_t sharedMemBytes, hipStream_t hStream, void** kernelParams,
|
|
||||||
void** extra, hipEvent_t startEvent, hipEvent_t stopEvent) {
|
|
||||||
HIP_INIT_API(hipModuleLaunchKernelExt, f, globalWorkSizeX, globalWorkSizeY, globalWorkSizeZ,
|
|
||||||
blockDimX, blockDimY, blockDimZ, sharedMemBytes, hStream, kernelParams, extra,
|
|
||||||
startEvent, stopEvent);
|
|
||||||
|
|
||||||
HIP_RETURN(ihipModuleLaunchKernel(f, globalWorkSizeX, globalWorkSizeY, globalWorkSizeZ, blockDimX,
|
|
||||||
blockDimY, blockDimZ, sharedMemBytes, hStream, kernelParams,
|
|
||||||
extra, startEvent, stopEvent));
|
|
||||||
}
|
|
||||||
|
|
||||||
hipError_t hipModuleLaunchCooperativeKernel(hipFunction_t f, unsigned int gridDimX,
|
hipError_t hipModuleLaunchCooperativeKernel(hipFunction_t f, unsigned int gridDimX,
|
||||||
unsigned int gridDimY, unsigned int gridDimZ,
|
unsigned int gridDimY, unsigned int gridDimZ,
|
||||||
unsigned int blockDimX, unsigned int blockDimY,
|
unsigned int blockDimX, unsigned int blockDimY,
|
||||||
|
|||||||
Reference in New Issue
Block a user